==> tripwire-open-source-2.4.3.5.tar.gz: tripwire-open-source-2.4.3.5/src/twtest/tasktimer_t.cpp <==
//
// The developer of the original code and/or files is Tripwire, Inc.
// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
// Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
// reserved.
// 
// This program is free software.  The contents of this file are subject
// to the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2 of the License, or (at your
// option) any later version.  You may redistribute it and/or modify it
// only in compliance with the GNU General Public License.
// 
// This program is distributed in the hope that it will be useful.
// However, this program is distributed AS-IS WITHOUT ANY
// WARRANTY; INCLUDING THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS
// FOR A PARTICULAR PURPOSE.  Please see the GNU General Public License
// for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
// 
// Nothing in the GNU General Public License or any other license to use
// the code or files shall permit you to use Tripwire's trademarks,
// service marks, or other intellectual property without Tripwire's
// prior written consent.
// 
// If you have any questions, please contact Tripwire, Inc. at either
// info@tripwire.org or www.tripwire.org.
//
// tasktimer_t -- test driver for cTaskTimer
#include "core/stdcore.h"

void TestTaskTimer()
{
}

==> tripwire-open-source-2.4.3.6.tar.gz: tripwire-open-source-2.4.3.6/src/twtest/tasktimer_t.cpp <==
//
// The developer of the original code and/or files is Tripwire, Inc.
// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
// Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
// reserved.
// 
// This program is free software.  The contents of this file are subject
// to the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2 of the License, or (at your
// option) any later version.  You may redistribute it and/or modify it
// only in compliance with the GNU General Public License.
// 
// This program is distributed in the hope that it will be useful.
// However, this program is distributed AS-IS WITHOUT ANY
// WARRANTY; INCLUDING THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS
// FOR A PARTICULAR PURPOSE.  Please see the GNU General Public License
// for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
// 
// Nothing in the GNU General Public License or any other license to use
// the code or files shall permit you to use Tripwire's trademarks,
// service marks, or other intellectual property without Tripwire's
// prior written consent.
// 
// If you have any questions, please contact Tripwire, Inc. at either
// info@tripwire.org or www.tripwire.org.
//
// tasktimer_t -- test driver for cTaskTimer
#include "core/stdcore.h"
#include "test.h"
#include "core/tasktimer.h"
#include <unistd.h>

void TestTaskTimer()
{
    cTaskTimer timer("unit testing");

    TEST(!timer.IsRunning());
    TEST(0 == timer.GetTotalTime());
    TEST(0 == timer.GetNumTimesStarted());

    for( int counter=0; counter<5; counter++)
    {
        timer.Start();
        TEST(timer.IsRunning());
        sleep(1);
        timer.Stop();
        TEST(!timer.IsRunning());
    }

    TEST(!timer.IsRunning());
    TEST(5 <= timer.GetTotalTime());
    TEST(5 == timer.GetNumTimesStarted());
}

void RegisterSuite_TaskTimer()
{
    RegisterTest("TaskTimer", "Basic", TestTaskTimer);
}
